@@ -1,5 +1,5 @@
 /* This file is part of Ganv.
- * Copyright 2007-2012 David Robillard <http://drobilla.net>
+ * Copyright 2007-2015 David Robillard <http://drobilla.net>
  *
  * Ganv is free software: you can redistribute it and/or modify it under the
  * terms of the GNU General Public License as published by the Free Software
@@ -16,12 +16,11 @@
 #ifndef GANV_GANV_HPP
 #define GANV_GANV_HPP
 
-#include "ganv/Canvas.hpp"
-#include "ganv/Circle.hpp"
-#include "ganv/Edge.hpp"
-#include "ganv/Module.hpp"
-#include "ganv/Node.hpp"
-#include "ganv/Port.hpp"
+#include "ganv/Canvas.hpp" // IWYU pragma: export
+#include "ganv/Circle.hpp" // IWYU pragma: export
+#include "ganv/Edge.hpp"   // IWYU pragma: export
+#include "ganv/Module.hpp" // IWYU pragma: export
+#include "ganv/Node.hpp"   // IWYU pragma: export
+#include "ganv/Port.hpp"   // IWYU pragma: export
 
 #endif // GANV_GANV_HPP
-
